Package: HPiP
Type: Package
Title: Host-Pathogen Interaction Prediction
Version: 1.19.0
Authors@R: c(
    person("Matineh", "Rahmatbakhsh", ,"matinerb.94@gmail.com",c("aut","trl","cre")),
    person("Mohan", "Babu", ,"mohan.babu@uregina.ca", c("led")))
Description: HPiP (Host-Pathogen Interaction Prediction) uses an ensemble learning 
    algorithm for prediction of host-pathogen protein-protein interactions (HP-PPIs) 
    using structural and physicochemical descriptors computed from amino 
    acid-composition of host and pathogen proteins.The proposed package can effectively address 
    data shortages and data unavailability for HP-PPI network reconstructions. 
    Moreover, establishing computational frameworks in that regard will reveal 
    mechanistic insights into infectious diseases and suggest potential HP-PPI targets, 
    thus narrowing down the range of possible candidates for subsequent wet-lab experimental validations.
Depends: R (>= 4.1)
Imports: dplyr (>= 1.0.6), httr (>= 1.4.2), readr, tidyr, tibble,
        utils, stringr, magrittr, caret, corrplot, ggplot2, pROC,
        PRROC, igraph, graphics, stats, purrr, grDevices, protr, MCL
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/mrbakhsh/HPiP
BugReports: https://github.com/mrbakhsh/HPiP/issues
VignetteBuilder: knitr
Suggests: rmarkdown, colorspace, e1071, kernlab, ranger,
        SummarizedExperiment, Biostrings, randomForest, gprofiler2,
        gridExtra, ggthemes, BiocStyle, BiocGenerics, RUnit, tools,
        knitr
biocViews: Proteomics, SystemsBiology, NetworkInference,
        StructuralPrediction, GenePrediction, Network
RoxygenNote: 7.3.1
git_url: https://git.bioconductor.org/packages/HPiP
git_branch: devel
git_last_commit: a85ff66
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:19:40 UTC; biocbuild
Author: Matineh Rahmatbakhsh [aut, trl, cre],
  Mohan Babu [led]
Maintainer: Matineh Rahmatbakhsh <matinerb.94@gmail.com>
