# Generated by roxygen2: do not edit by hand

export(FSmethod)
export(FreqInteractors)
export(calculateAAC)
export(calculateAutocor)
export(calculateBE)
export(calculateCTDC)
export(calculateCTDD)
export(calculateCTDT)
export(calculateCTriad)
export(calculateDC)
export(calculateF)
export(calculateKSAAP)
export(calculateQD_Sm)
export(calculateTC)
export(calculateTC_Sm)
export(corr_plot)
export(enrichfindP)
export(enrichfind_cpx)
export(enrichfind_hp)
export(enrichplot)
export(filter_missing_values)
export(getFASTA)
export(getHPI)
export(get_negativePPI)
export(get_positivePPI)
export(impute_missing_data)
export(plotPPI)
export(pred_ensembel)
export(run_clustering)
export(var_imp)
importFrom(MCL,mcl)
importFrom(PRROC,pr.curve)
importFrom(caret,predictors)
importFrom(caret,rfFuncs)
importFrom(caret,rfeControl)
importFrom(caret,train)
importFrom(caret,trainControl)
importFrom(caret,twoClassSummary)
importFrom(caret,varImp)
importFrom(corrplot,corrplot)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotation_custom)
importFrom(ggplot2,coord_equal)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_gradient2)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,unit)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(igraph,E)
importFrom(igraph,cluster_label_prop)
importFrom(igraph,cluster_louvain)
importFrom(igraph,cluster_walktrap)
importFrom(igraph,fastgreedy.community)
importFrom(igraph,get.adjacency)
importFrom(igraph,graph.adjacency)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,membership)
importFrom(igraph,simplify)
importFrom(magrittr,"%>%")
importFrom(magrittr,set_rownames)
importFrom(pROC,ggroc)
importFrom(pROC,plot.roc)
importFrom(pROC,roc)
importFrom(protr,readFASTA)
importFrom(purrr,map_df)
importFrom(readr,col_character)
importFrom(readr,col_double)
importFrom(readr,cols)
importFrom(stats,aggregate)
importFrom(stats,cor)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,reorder)
importFrom(stats,sd)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_split)
importFrom(tibble,add_column)
importFrom(tibble,rownames_to_column)
importFrom(tidyr,gather)
importFrom(tidyr,separate)
importFrom(tidyr,spread)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
