# README
- `AAidx.csv` includes amino acid properties that are retrieved
from [AAindex Database](https://www.genome.jp/dbget/aaindex.html).
- `UP000464024.fasta` includes fasta sequences for SARS-CoV-2 viral proteins,
extracted directly from [UniProt database](https://www.uniprot.org/).
- `TP_set.csv` includes interaction between SARS-CoV-2 and host proteins, 
retrieved from [BioGrid database](https://thebiogrid.org/), and for the sake of 
example, we randomly selected 100 interactions from all pairs.
