    #' Input Data for Prediction Algorithm
    #' @description Input data for \code{\link[HPiP]{pred_ensembel}}
    #' @name example_data
    #' @usage data(example_data)
    #' @docType data
    #' @format
    #' a data.frame containing unlabeled or labeled HP-PPIs and pre-computed
    #' numerical features.
    NULL
