    #' Enrichment Result
    #' @description Input data for \code{\link[HPiP]{enrichplot}}
    #' @details
    #' To construct this dataset, predicted interactions, generated
    #' from \code{\link[HPiP]{pred_ensembel}} was used as data input for
    #' \code{\link[HPiP]{enrichplot}}.
    #' @name enrich.df
    #' @usage data(enrich.df)
    #' @docType data
    NULL
