    #' Data.frame Containing SARS-CoV-2 FASTA Sequences
    #' @description This data includes one protein sequence per SARS-CoV-2 gene,
    #' retrieved directly from UniProt database using
    #' \code{\link[HPiP]{getFASTA}}.
    #' @name UP000464024_df
    #' @usage data(UP000464024_df)
    #' @docType data
    #' @format A data.frame with two columns:(1) UniprotKBID, UniProt
    #' identifier.(2) FASTASEQ, sequences per SARS-CoV-2 gene.
    #' @source \url{https://www.uniprot.org/uniprot/?query=proteome:UP000464024}
    NULL
