% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predicted_PPIs.R
\docType{data}
\name{predicted_PPIs}
\alias{predicted_PPIs}
\title{Predicted HP-PPIs}
\usage{
data(predicted_PPIs)
}
\description{
Input data for \code{\link[HPiP]{enrichfindP}}
}
